==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/Save/ts/Save_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Die Datei &apos;%1&apos; besteht bereits. Möchten Sie die bestehende Datei überschreiben?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Alle Benutzerdefinierten Farben werden auf die nächste verfügbare Farbe gerundet.</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>File Format Version Not Recommended</source>
        <translation>Dateiversion nicht empfohlen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>Die benutzte Dateiformatversion wird nicht empfohlen: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Alle schwarzen Objekte und Layer werden weiss gespeichert.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>Weiterfahren?</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Saved drawing:</source>
        <translation>Zeichnung gespeichert:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translation type="obsolete">Alle Benutzerdefinierten Farben werden auf die nächste verfügbare Farbe gerundet. Weiterfahren?</translation>
    </message>
    <message>
        <location line="-25"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Speichere mit Dateiformat Version &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Schwarze Objekte und Layer werden als weiss gespeichert.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Benutzerdefinierte Farben werden auf die nächste verfügbare Farbe gerundet.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translation type="obsolete">Gespeicherte Zeichung: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="../Save.js" line="-42"/>
        <source>Overwrite File?</source>
        <translation>Datei überschreiben?</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translation type="obsolete">Die Datei &quot;%1&quot; besteht bereits. Möchten Sie die bestehende Datei überschreiben?</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Saving...</source>
        <translation>Speichern...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>File %1 has not been saved.</source>
        <translation>Datei %1 konnte nicht gespeichert werden.</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/Save/ts/Save_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Die Datei &apos;%1&apos; besteht bereits. Möchten Sie die bestehende Datei überschreiben?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Alle Benutzerdefinierten Farben werden auf die nächste verfügbare Farbe gerundet.</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>File Format Version Not Recommended</source>
        <translation>Dateiversion nicht empfohlen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>Die benutzte Dateiformatversion wird nicht empfohlen: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Alle schwarzen Objekte und Layer werden weiss gespeichert.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>Weiterfahren?</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Saved drawing:</source>
        <translation>Zeichnung gespeichert:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translation type="obsolete">Alle Benutzerdefinierten Farben werden auf die nächste verfügbare Farbe gerundet. Weiterfahren?</translation>
    </message>
    <message>
        <location line="-26"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Speichere mit Dateiformat Version &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Schwarze Objekte und Layer werden als weiss gespeichert.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Benutzerdefinierte Farben werden auf die nächste verfügbare Farbe &apos;gerundet&apos;.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translation type="obsolete">Gespeicherte Zeichung: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="../Save.js" line="-42"/>
        <source>Overwrite File?</source>
        <translation>Datei überschreiben?</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translation type="obsolete">Die Datei &quot;%1&quot; besteht bereits. Möchten Sie die bestehende Datei überschreiben?</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Saving...</source>
        <translation>Speichern...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>File %1 has not been saved.</source>
        <translation>Datei %1 konnte nicht gespeichert werden.</translation>
    </message>
</context>
</TS>
